"""
A module for every constant of symmetric.
"""


# Logs
LOG_FILE_NAME = "symmetric.log"

# API token authentication
API_CLIENT_TOKEN_NAME = "symmetric_api_key"
API_SERVER_TOKEN_NAME = "SYMMETRIC_API_KEY"
API_DEFAULT_TOKEN = "symmetric_token"
